Learn R Programming

CalcThemAll.PRM (version 1.1.1)

find_wet_season_end: Find Wet Season End Date

Description

Find Wet Season End Date

Usage

find_wet_season_end(wet_season_start, wet_season_length = 182)

Value

A character vector

Arguments

wet_season_start

A vector of dates signifying the first day of the wet season for site year combinations.

wet_season_length

The length of the wet season in days.

Examples

Run this code
wet_season_start_dates <- as.Date(c("2014-10-04", "2014-12-30", "2015-09-12"))
wet_season_end_dates <- find_wet_season_end(wet_season_start_dates)
#cut of date for the sampling year will be last day of June

Run the code above in your browser using DataLab