Learn R Programming

CalcThemAll.PRM (version 1.1.1)

pesticide_info: Pesticide Information for Pesticide Risk Metric Calculations (Reference Table)

Description

A reference table for PRM calculations in this package that include pesticide information such as type, species sensitivity distribution distributions and relevant equation variables.

Usage

pesticide_info

Arguments

Format

pesticide_info

A data frame with 62 rows and 9 columns:

pesticide

Pesticide name

relative_LOR

The relative Limit of Reporting replacement value

pesticide_type

The pesticide method of effect

distribution_type

The species sensitivity distribution shape/type

shape_location, shape_location2, scale, scale2, weight

Species sensitivity distribution variables used in PRM calculations

...